<template>
  <div :class="['preview-image-wrapper', wrapperClassName]">
    <Image @tap="handeClick" :mode="mode" :src="src" v-bind="$attrs" />
  </div>
</template>

<script setup lang="ts">
import { Image, ITouchEvent } from '@tarojs/components';
import Taro from '@tarojs/taro';
import { previewImageProps } from './previewImage';
import { reactive, computed, watch } from 'vue';

defineOptions({
  name: 'PreviewImage',
  inheritAttrs: false,
});

const props = defineProps(previewImageProps);

const state = reactive({
  width: 0,
  height: 0,
  isLoaded: false,
});

const mode = computed(() => (state.width > state.height ? 'heightFix' : 'widthFix'));

watch(
  () => props.src,
  () => {
    if (props.src) {
      Taro.getImageInfo({
        src: props.src,
        success(result) {
          state.width = result.width;
          state.height = result.height;
          state.isLoaded = true;
        },
      });
    }
  },
  {
    immediate: true,
  }
);

function handeClick(event: ITouchEvent) {
  if (props.onClick) {
    props.onClick(event);
  } else {
    Taro.previewImage({
      current: props.src,
      urls: props.urls.length > 0 ? props.urls : [props.src],
    });
  }
}
</script>
